@@ -362,7 +362,7 @@ BEGIN {
         downloadLimit         => number,
         downloadLimited       => boolean,
         honorsSessionLimits   => boolean,
-        seedRatioLimit        => number,
+        seedRatioLimit        => double,
         seedRatioMode         => number,
         uploadLimit           => number,
         uploadLimited         => boolean,
@@ -395,12 +395,12 @@ BEGIN {
         peersGettingFromUs          => number,
         peersKnown                  => number,
         peersSendingToUs            => number,
-        percentDone                 => number,
+        percentDone                 => double,
         pieceCount                  => number,
         pieceSize                   => number,
         rateDownload                => number,
         rateUpload                  => number,
-        recheckProgress             => number,
+        recheckProgress             => double,
         seeders                     => number,
         sizeWhenDone                => number,
         startDate                   => number,
@@ -410,7 +410,7 @@ BEGIN {
         totalSize                   => number,
         torrentFile                 => string,
         uploadedEver                => number,
-        uploadRatio                 => number,
+        uploadRatio                 => double,
         webseedsSendingToUs         => number,
     );
         #peers                       => array,
